.. _image-plotting:

Image plotting
==============

`gammapy.image` provides a few helper functions and classes to create
publication-quality images.

Colormaps
---------

The following example shows how to plot images using colormaps that are commonly
used in gamma-ray astronomy (`~gammapy.image.colormap_hess` and
`~gammapy.image.colormap_milagro`).

.. plot:: image/colormap_example.py
